Class: Aws::CodeCatalyst::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodeCatalyst::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codecatalyst/client.rb,
sig/client.rbs
Overview
An API client for CodeCatalyst. To construct a client, you need to configure a :region and :credentials.
client = Aws::CodeCatalyst::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAccessTokenResponseSuccess, _CreateDevEnvironmentResponseSuccess, _CreateProjectResponseSuccess, _CreateSourceRepositoryBranchResponseSuccess, _CreateSourceRepositoryResponseSuccess, _DeleteAccessTokenResponseSuccess, _DeleteDevEnvironmentResponseSuccess, _DeleteProjectResponseSuccess, _DeleteSourceRepositoryResponseSuccess, _DeleteSpaceResponseSuccess, _GetDevEnvironmentResponseSuccess, _GetProjectResponseSuccess, _GetSourceRepositoryCloneUrlsResponseSuccess, _GetSourceRepositoryResponseSuccess, _GetSpaceResponseSuccess, _GetSubscriptionResponseSuccess, _GetUserDetailsResponseSuccess, _GetWorkflowResponseSuccess, _GetWorkflowRunResponseSuccess, _ListAccessTokensResponseSuccess, _ListDevEnvironmentSessionsResponseSuccess, _ListDevEnvironmentsResponseSuccess, _ListEventLogsResponseSuccess, _ListProjectsResponseSuccess, _ListSourceRepositoriesResponseSuccess, _ListSourceRepositoryBranchesResponseSuccess, _ListSpacesResponseSuccess, _ListWorkflowRunsResponseSuccess, _ListWorkflowsResponseSuccess, _StartDevEnvironmentResponseSuccess, _StartDevEnvironmentSessionResponseSuccess, _StartWorkflowRunResponseSuccess, _StopDevEnvironmentResponseSuccess, _StopDevEnvironmentSessionResponseSuccess, _UpdateDevEnvironmentResponseSuccess, _UpdateProjectResponseSuccess, _UpdateSpaceResponseSuccess, _VerifySessionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_access_token(params = {}) ⇒ Types::CreateAccessTokenResponse
Creates a personal access token (PAT) for the current user.
-
#create_dev_environment(params = {}) ⇒ Types::CreateDevEnvironmentResponse
Creates a Dev Environment in Amazon CodeCatalyst, a cloud-based development environment that you can use to quickly work on the code stored in the source repositories of your project.
-
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a project in a specified space.
-
#create_source_repository(params = {}) ⇒ Types::CreateSourceRepositoryResponse
Creates an empty Git-based source repository in a specified project.
-
#create_source_repository_branch(params = {}) ⇒ Types::CreateSourceRepositoryBranchResponse
Creates a branch in a specified source repository in Amazon CodeCatalyst.
-
#delete_access_token(params = {}) ⇒ Struct
Deletes a specified personal access token (PAT).
-
#delete_dev_environment(params = {}) ⇒ Types::DeleteDevEnvironmentResponse
Deletes a Dev Environment.
-
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes a project in a space.
-
#delete_source_repository(params = {}) ⇒ Types::DeleteSourceRepositoryResponse
Deletes a source repository in Amazon CodeCatalyst.
-
#delete_space(params = {}) ⇒ Types::DeleteSpaceResponse
Deletes a space.
-
#get_dev_environment(params = {}) ⇒ Types::GetDevEnvironmentResponse
Returns information about a Dev Environment for a source repository in a project.
-
#get_project(params = {}) ⇒ Types::GetProjectResponse
Returns information about a project.
-
#get_source_repository(params = {}) ⇒ Types::GetSourceRepositoryResponse
Returns information about a source repository.
-
#get_source_repository_clone_urls(params = {}) ⇒ Types::GetSourceRepositoryCloneUrlsResponse
Returns information about the URLs that can be used with a Git client to clone a source repository.
-
#get_space(params = {}) ⇒ Types::GetSpaceResponse
Returns information about an space.
-
#get_subscription(params = {}) ⇒ Types::GetSubscriptionResponse
Returns information about the Amazon Web Services account used for billing purposes and the billing plan for the space.
-
#get_user_details(params = {}) ⇒ Types::GetUserDetailsResponse
Returns information about a user.
-
#get_workflow(params = {}) ⇒ Types::GetWorkflowResponse
Returns information about a workflow.
-
#get_workflow_run(params = {}) ⇒ Types::GetWorkflowRunResponse
Returns information about a specified run of a workflow.
-
#list_access_tokens(params = {}) ⇒ Types::ListAccessTokensResponse
Lists all personal access tokens (PATs) associated with the user who calls the API.
-
#list_dev_environment_sessions(params = {}) ⇒ Types::ListDevEnvironmentSessionsResponse
Retrieves a list of active sessions for a Dev Environment in a project.
-
#list_dev_environments(params = {}) ⇒ Types::ListDevEnvironmentsResponse
Retrieves a list of Dev Environments in a project.
-
#list_event_logs(params = {}) ⇒ Types::ListEventLogsResponse
Retrieves a list of events that occurred during a specific time in a space.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Retrieves a list of projects.
-
#list_source_repositories(params = {}) ⇒ Types::ListSourceRepositoriesResponse
Retrieves a list of source repositories in a project.
-
#list_source_repository_branches(params = {}) ⇒ Types::ListSourceRepositoryBranchesResponse
Retrieves a list of branches in a specified source repository.
-
#list_spaces(params = {}) ⇒ Types::ListSpacesResponse
Retrieves a list of spaces.
-
#list_workflow_runs(params = {}) ⇒ Types::ListWorkflowRunsResponse
Retrieves a list of workflow runs of a specified workflow.
-
#list_workflows(params = {}) ⇒ Types::ListWorkflowsResponse
Retrieves a list of workflows in a specified project.
-
#start_dev_environment(params = {}) ⇒ Types::StartDevEnvironmentResponse
Starts a specified Dev Environment and puts it into an active state.
-
#start_dev_environment_session(params = {}) ⇒ Types::StartDevEnvironmentSessionResponse
Starts a session for a specified Dev Environment.
-
#start_workflow_run(params = {}) ⇒ Types::StartWorkflowRunResponse
Begins a run of a specified workflow.
-
#stop_dev_environment(params = {}) ⇒ Types::StopDevEnvironmentResponse
Pauses a specified Dev Environment and places it in a non-running state.
-
#stop_dev_environment_session(params = {}) ⇒ Types::StopDevEnvironmentSessionResponse
Stops a session for a specified Dev Environment.
-
#update_dev_environment(params = {}) ⇒ Types::UpdateDevEnvironmentResponse
Changes one or more values for a Dev Environment.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Changes one or more values for a project.
-
#update_space(params = {}) ⇒ Types::UpdateSpaceResponse
Changes one or more values for a space.
-
#verify_session(params = {}) ⇒ Types::VerifySessionResponse
Verifies whether the calling user has a valid Amazon CodeCatalyst login and session.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-codecatalyst/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2504 2505 2506 |
# File 'lib/aws-sdk-codecatalyst/client.rb', line 2504 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2507 2508 2509 |
# File 'lib/aws-sdk-codecatalyst/client.rb', line 2507 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 |
# File 'lib/aws-sdk-codecatalyst/client.rb', line 2477 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodeCatalyst') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codecatalyst' context[:gem_version] = '1.52.0' Seahorse::Client::Request.new(handlers, context) end |
#create_access_token(params = {}) ⇒ Types::CreateAccessTokenResponse
Creates a personal access token (PAT) for the current user. A personal access token (PAT) is similar to a password. It is associated with your user identity for use across all spaces and projects in Amazon CodeCatalyst. You use PATs to access CodeCatalyst from resources that include integrated development environments (IDEs) and Git-based source repositories. PATs represent you in Amazon CodeCatalyst and you can manage them in your user settings.For more information, see Managing personal access tokens in Amazon CodeCatalyst.
89 |
# File 'sig/client.rbs', line 89
def create_access_token: (
|
#create_dev_environment(params = {}) ⇒ Types::CreateDevEnvironmentResponse
Creates a Dev Environment in Amazon CodeCatalyst, a cloud-based development environment that you can use to quickly work on the code stored in the source repositories of your project.
103 |
# File 'sig/client.rbs', line 103
def create_dev_environment: (
|
#create_project(params = {}) ⇒ Types::CreateProjectResponse
Creates a project in a specified space.
137 |
# File 'sig/client.rbs', line 137
def create_project: (
|
#create_source_repository(params = {}) ⇒ Types::CreateSourceRepositoryResponse
Creates an empty Git-based source repository in a specified project.
The repository is created with an initial empty commit with a default
branch named main.
152 |
# File 'sig/client.rbs', line 152
def create_source_repository: (
|
#create_source_repository_branch(params = {}) ⇒ Types::CreateSourceRepositoryBranchResponse
Creates a branch in a specified source repository in Amazon CodeCatalyst.
168 |
# File 'sig/client.rbs', line 168
def create_source_repository_branch: (
|
#delete_access_token(params = {}) ⇒ Struct
Deletes a specified personal access token (PAT). A personal access token can only be deleted by the user who created it.
181 |
# File 'sig/client.rbs', line 181
def delete_access_token: (
|
#delete_dev_environment(params = {}) ⇒ Types::DeleteDevEnvironmentResponse
Deletes a Dev Environment.
193 |
# File 'sig/client.rbs', line 193
def delete_dev_environment: (
|
#delete_project(params = {}) ⇒ Types::DeleteProjectResponse
Deletes a project in a space.
207 |
# File 'sig/client.rbs', line 207
def delete_project: (
|
#delete_source_repository(params = {}) ⇒ Types::DeleteSourceRepositoryResponse
Deletes a source repository in Amazon CodeCatalyst. You cannot use this API to delete a linked repository. It can only be used to delete a Amazon CodeCatalyst source repository.
220 |
# File 'sig/client.rbs', line 220
def delete_source_repository: (
|
#delete_space(params = {}) ⇒ Types::DeleteSpaceResponse
Deletes a space.
Deleting a space cannot be undone. Additionally, since space names must be unique across Amazon CodeCatalyst, you cannot reuse names of deleted spaces.
233 |
# File 'sig/client.rbs', line 233
def delete_space: (
|
#get_dev_environment(params = {}) ⇒ Types::GetDevEnvironmentResponse
Returns information about a Dev Environment for a source repository in a project. Dev Environments are specific to the user who creates them.
256 |
# File 'sig/client.rbs', line 256
def get_dev_environment: (
|
#get_project(params = {}) ⇒ Types::GetProjectResponse
Returns information about a project.
271 |
# File 'sig/client.rbs', line 271
def get_project: (
|
#get_source_repository(params = {}) ⇒ Types::GetSourceRepositoryResponse
Returns information about a source repository.
287 |
# File 'sig/client.rbs', line 287
def get_source_repository: (
|
#get_source_repository_clone_urls(params = {}) ⇒ Types::GetSourceRepositoryCloneUrlsResponse
Returns information about the URLs that can be used with a Git client to clone a source repository.
299 |
# File 'sig/client.rbs', line 299
def get_source_repository_clone_urls: (
|
#get_space(params = {}) ⇒ Types::GetSpaceResponse
Returns information about an space.
314 |
# File 'sig/client.rbs', line 314
def get_space: (
|
#get_subscription(params = {}) ⇒ Types::GetSubscriptionResponse
Returns information about the Amazon Web Services account used for billing purposes and the billing plan for the space.
327 |
# File 'sig/client.rbs', line 327
def get_subscription: (
|
#get_user_details(params = {}) ⇒ Types::GetUserDetailsResponse
Returns information about a user.
341 |
# File 'sig/client.rbs', line 341
def get_user_details: (
|
#get_workflow(params = {}) ⇒ Types::GetWorkflowResponse
Returns information about a workflow.
362 |
# File 'sig/client.rbs', line 362
def get_workflow: (
|
#get_workflow_run(params = {}) ⇒ Types::GetWorkflowRunResponse
Returns information about a specified run of a workflow.
382 |
# File 'sig/client.rbs', line 382
def get_workflow_run: (
|
#list_access_tokens(params = {}) ⇒ Types::ListAccessTokensResponse
Lists all personal access tokens (PATs) associated with the user who calls the API. You can only list PATs associated with your Amazon Web Services Builder ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
395 |
# File 'sig/client.rbs', line 395
def list_access_tokens: (
|
#list_dev_environment_sessions(params = {}) ⇒ Types::ListDevEnvironmentSessionsResponse
Retrieves a list of active sessions for a Dev Environment in a project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
407 |
# File 'sig/client.rbs', line 407
def list_dev_environment_sessions: (
|
#list_dev_environments(params = {}) ⇒ Types::ListDevEnvironmentsResponse
Retrieves a list of Dev Environments in a project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
422 |
# File 'sig/client.rbs', line 422
def list_dev_environments: (
|
#list_event_logs(params = {}) ⇒ Types::ListEventLogsResponse
Retrieves a list of events that occurred during a specific time in a space. You can use these events to audit user and system activity in a space. For more information, see Monitoring in the Amazon CodeCatalyst User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
443 |
# File 'sig/client.rbs', line 443
def list_event_logs: (
|
#list_projects(params = {}) ⇒ Types::ListProjectsResponse
Retrieves a list of projects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
459 |
# File 'sig/client.rbs', line 459
def list_projects: (
|
#list_source_repositories(params = {}) ⇒ Types::ListSourceRepositoriesResponse
Retrieves a list of source repositories in a project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
479 |
# File 'sig/client.rbs', line 479
def list_source_repositories: (
|
#list_source_repository_branches(params = {}) ⇒ Types::ListSourceRepositoryBranchesResponse
Retrieves a list of branches in a specified source repository.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
493 |
# File 'sig/client.rbs', line 493
def list_source_repository_branches: (
|
#list_spaces(params = {}) ⇒ Types::ListSpacesResponse
Retrieves a list of spaces.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
508 |
# File 'sig/client.rbs', line 508
def list_spaces: (
|
#list_workflow_runs(params = {}) ⇒ Types::ListWorkflowRunsResponse
Retrieves a list of workflow runs of a specified workflow.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
519 |
# File 'sig/client.rbs', line 519
def list_workflow_runs: (
|
#list_workflows(params = {}) ⇒ Types::ListWorkflowsResponse
Retrieves a list of workflows in a specified project.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
538 |
# File 'sig/client.rbs', line 538
def list_workflows: (
|
#start_dev_environment(params = {}) ⇒ Types::StartDevEnvironmentResponse
Starts a specified Dev Environment and puts it into an active state.
558 |
# File 'sig/client.rbs', line 558
def start_dev_environment: (
|
#start_dev_environment_session(params = {}) ⇒ Types::StartDevEnvironmentSessionResponse
Starts a session for a specified Dev Environment.
582 |
# File 'sig/client.rbs', line 582
def start_dev_environment_session: (
|
#start_workflow_run(params = {}) ⇒ Types::StartWorkflowRunResponse
Begins a run of a specified workflow.
604 |
# File 'sig/client.rbs', line 604
def start_workflow_run: (
|
#stop_dev_environment(params = {}) ⇒ Types::StopDevEnvironmentResponse
Pauses a specified Dev Environment and places it in a non-running state. Stopped Dev Environments do not consume compute minutes.
620 |
# File 'sig/client.rbs', line 620
def stop_dev_environment: (
|
#stop_dev_environment_session(params = {}) ⇒ Types::StopDevEnvironmentSessionResponse
Stops a session for a specified Dev Environment.
635 |
# File 'sig/client.rbs', line 635
def stop_dev_environment_session: (
|
#update_dev_environment(params = {}) ⇒ Types::UpdateDevEnvironmentResponse
Changes one or more values for a Dev Environment. Updating certain values of the Dev Environment will cause a restart.
655 |
# File 'sig/client.rbs', line 655
def update_dev_environment: (
|
#update_project(params = {}) ⇒ Types::UpdateProjectResponse
Changes one or more values for a project.
680 |
# File 'sig/client.rbs', line 680
def update_project: (
|
#update_space(params = {}) ⇒ Types::UpdateSpaceResponse
Changes one or more values for a space.
694 |
# File 'sig/client.rbs', line 694
def update_space: (
|
#verify_session(params = {}) ⇒ Types::VerifySessionResponse
Verifies whether the calling user has a valid Amazon CodeCatalyst login and session. If successful, this returns the ID of the user in Amazon CodeCatalyst.
705 706 |
# File 'sig/client.rbs', line 705
def verify_session: () -> _VerifySessionResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _VerifySessionResponseSuccess
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2497 2498 2499 |
# File 'lib/aws-sdk-codecatalyst/client.rb', line 2497 def waiter_names [] end |