Class: Aws::CodeCatalyst::Types::EventLogEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecatalyst/types.rb

Overview

Information about an entry in an event log of Amazon CodeCatalyst activity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

The code of the error, if any.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#event_categoryString

The category for the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#event_nameString

The name of the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#event_sourceString

The source of the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#event_timeTime

The time the event took place, in coordinated universal time (UTC) timestamp format as specified in RFC 3339.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#event_typeString

The type of the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The system-generated unique ID of the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#operation_typeString

The type of the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#project_informationTypes::ProjectInformation

Information about the project where the event occurred.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The system-generated unique ID of the request.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#request_payloadTypes::EventPayload

Information about the payload of the request.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#response_payloadTypes::EventPayload

Information about the payload of the response, if any.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#source_ip_addressString

The IP address of the user whose actions are recorded in the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#user_agentString



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end

#user_identityTypes::UserIdentity

The system-generated unique ID of the user whose actions are recorded in the event.



640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640

class EventLogEntry < Struct.new(
  :id,
  :event_name,
  :event_type,
  :event_category,
  :event_source,
  :event_time,
  :operation_type,
  :user_identity,
  :project_information,
  :request_id,
  :request_payload,
  :response_payload,
  :error_code,
  :source_ip_address,
  :user_agent)
  SENSITIVE = []
  include Aws::Structure
end