Class: Aws::CodeCatalyst::Types::GetDevEnvironmentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecatalyst/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aliasString

The user-specified alias for the Dev Environment.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#creator_idString

The system-generated unique ID of the user who created the Dev Environment.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The system-generated unique ID of the Dev Environment.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#idesArray<Types::Ide>

Information about the integrated development environment (IDE) configured for the Dev Environment.

Returns:



809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#inactivity_timeout_minutesInteger

The amount of time the Dev Environment will run without any activity detected before stopping, in minutes.

Returns:

  • (Integer)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The Amazon EC2 instace type to use for the Dev Environment.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeTime

The time when the Dev Environment was last updated, in coordinated universal time (UTC) timestamp format as specified in RFC 3339.

Returns:

  • (Time)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#persistent_storageTypes::PersistentStorage

Information about the amount of storage allocated to the Dev Environment. By default, a Dev Environment is configured to have 16GB of persistent storage.



809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#project_nameString

The name of the project in the space.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#repositoriesArray<Types::DevEnvironmentRepositorySummary>

The source repository that contains the branch cloned into the Dev Environment.



809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#space_nameString

The name of the space.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the Dev Environment.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The reason for the status.

Returns:

  • (String)


809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809

class GetDevEnvironmentResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :last_updated_time,
  :creator_id,
  :status,
  :status_reason,
  :repositories,
  :alias,
  :ides,
  :instance_type,
  :inactivity_timeout_minutes,
  :persistent_storage)
  SENSITIVE = []
  include Aws::Structure
end