Class: Aws::CodeCatalyst::Types::GetWorkflowResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecatalyst/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_time ⇒ Time

The date and time the workflow was created, in coordinated universal time (UTC) timestamp format as specified in RFC 3339

Returns:

  • (Time)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#definition ⇒ Types::WorkflowDefinition

Information about the workflow definition file for the workflow.



1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The ID of the workflow.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_time ⇒ Time

The date and time the workflow was last updated, in coordinated universal time (UTC) timestamp format as specified in RFC 3339

Returns:

  • (Time)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the workflow.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#project_name ⇒ String

The name of the project in the space.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#run_mode ⇒ String

The behavior to use when multiple workflows occur at the same time. For more information, see https://docs.aws.amazon.com/codecatalyst/latest/userguide/workflows-configure-runs.html in the Amazon CodeCatalyst User Guide.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#source_branch_name ⇒ String

The name of the branch that contains the workflow YAML.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#source_repository_name ⇒ String

The name of the source repository where the workflow YAML is stored.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#space_name ⇒ String

The name of the space.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the workflow.

Returns:

  • (String)


1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1446

class GetWorkflowResponse < Struct.new(
  :space_name,
  :project_name,
  :id,
  :name,
  :source_repository_name,
  :source_branch_name,
  :definition,
  :created_time,
  :last_updated_time,
  :run_mode,
  :status)
  SENSITIVE = []
  include Aws::Structure
end