Class: Aws::CodeCatalyst::Types::PersistentStorageConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecatalyst/types.rb

Overview

Information about the configuration of persistent storage for a Dev Environment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#size_in_gi_bInteger

The size of the persistent storage in gigabytes (specifically GiB).

Valid values for storage are based on memory sizes in 16GB increments. Valid values are 16, 32, and 64.

Returns:

  • (Integer)


1532
1533
1534
1535
1536
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1532

class PersistentStorageConfiguration < Struct.new(
  :size_in_gi_b)
  SENSITIVE = []
  include Aws::Structure
end