Class: Aws::CodeCatalyst::Types::ProjectSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCatalyst::Types::ProjectSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecatalyst/types.rb
Overview
Information about a project.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the project.
-
#display_name ⇒ String
The friendly name displayed to users of the project in Amazon CodeCatalyst.
-
#name ⇒ String
The name of the project in the space.
Instance Attribute Details
#description ⇒ String
The description of the project.
1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1599 class ProjectSummary < Struct.new( :name, :display_name, :description) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The friendly name displayed to users of the project in Amazon CodeCatalyst.
1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1599 class ProjectSummary < Struct.new( :name, :display_name, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the project in the space.
1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1599 class ProjectSummary < Struct.new( :name, :display_name, :description) SENSITIVE = [] include Aws::Structure end |