Class: Aws::CodeCatalyst::Types::UpdateDevEnvironmentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCatalyst::Types::UpdateDevEnvironmentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecatalyst/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The user-specified alias for the Dev Environment.
-
#client_token ⇒ String
A user-specified idempotency token.
-
#id ⇒ String
The system-generated unique ID of the Dev Environment.
-
#ides ⇒ Array<Types::IdeConfiguration>
Information about the integrated development environment (IDE) configured for a Dev Environment.
-
#inactivity_timeout_minutes ⇒ Integer
The amount of time the Dev Environment will run without any activity detected before stopping, in minutes.
-
#instance_type ⇒ String
The Amazon EC2 instace type to use for the Dev Environment.
-
#project_name ⇒ String
The name of the project in the space.
-
#space_name ⇒ String
The name of the space.
Instance Attribute Details
#alias ⇒ String
The user-specified alias for the Dev Environment. Changing this value will not cause a restart.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A user-specified idempotency token. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries return the result from the original successful request and have no additional effect.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The system-generated unique ID of the Dev Environment.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |
#ides ⇒ Array<Types::IdeConfiguration>
Information about the integrated development environment (IDE) configured for a Dev Environment.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |
#inactivity_timeout_minutes ⇒ Integer
The amount of time the Dev Environment will run without any activity detected before stopping, in minutes. Only whole integers are allowed. Dev Environments consume compute minutes when running.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The Amazon EC2 instace type to use for the Dev Environment.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the project in the space.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |
#space_name ⇒ String
The name of the space.
1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1982 class UpdateDevEnvironmentRequest < Struct.new( :space_name, :project_name, :id, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :client_token) SENSITIVE = [] include Aws::Structure end |