Class: Aws::CodeCatalyst::Types::ValidationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codecatalyst/types.rb

Overview

The request was denied because an input failed to satisfy the constraints specified by the service. Check the spelling and input requirements, and then try again.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2088
2089
2090
2091
2092
# File 'lib/aws-sdk-codecatalyst/types.rb', line 2088

class ValidationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end