Class: Aws::CodeCatalyst::Types::EventLogEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCatalyst::Types::EventLogEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecatalyst/types.rb
Overview
Information about an entry in an event log of Amazon CodeCatalyst activity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The code of the error, if any.
-
#event_category ⇒ String
The category for the event.
-
#event_name ⇒ String
The name of the event.
-
#event_source ⇒ String
The source of the event.
-
#event_time ⇒ Time
The time the event took place, in coordinated universal time (UTC) timestamp format as specified in [RFC 3339][1].
-
#event_type ⇒ String
The type of the event.
-
#id ⇒ String
The system-generated unique ID of the event.
-
#operation_type ⇒ String
The type of the event.
-
#project_information ⇒ Types::ProjectInformation
Information about the project where the event occurred.
-
#request_id ⇒ String
The system-generated unique ID of the request.
-
#request_payload ⇒ Types::EventPayload
Information about the payload of the request.
-
#response_payload ⇒ Types::EventPayload
Information about the payload of the response, if any.
-
#source_ip_address ⇒ String
The IP address of the user whose actions are recorded in the event.
- #user_agent ⇒ String
-
#user_identity ⇒ Types::UserIdentity
The system-generated unique ID of the user whose actions are recorded in the event.
Instance Attribute Details
#error_code ⇒ String
The code of the error, if any.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#event_category ⇒ String
The category for the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#event_name ⇒ String
The name of the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#event_source ⇒ String
The source of the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#event_time ⇒ Time
The time the event took place, in coordinated universal time (UTC) timestamp format as specified in RFC 3339.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#event_type ⇒ String
The type of the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The system-generated unique ID of the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#operation_type ⇒ String
The type of the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#project_information ⇒ Types::ProjectInformation
Information about the project where the event occurred.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The system-generated unique ID of the request.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#request_payload ⇒ Types::EventPayload
Information about the payload of the request.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#response_payload ⇒ Types::EventPayload
Information about the payload of the response, if any.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#source_ip_address ⇒ String
The IP address of the user whose actions are recorded in the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#user_agent ⇒ String
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |
#user_identity ⇒ Types::UserIdentity
The system-generated unique ID of the user whose actions are recorded in the event.
640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 640 class EventLogEntry < Struct.new( :id, :event_name, :event_type, :event_category, :event_source, :event_time, :operation_type, :user_identity, :project_information, :request_id, :request_payload, :response_payload, :error_code, :source_ip_address, :user_agent) SENSITIVE = [] include Aws::Structure end |