Class: Aws::CodeCatalyst::Types::GetDevEnvironmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCatalyst::Types::GetDevEnvironmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecatalyst/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias ⇒ String
The user-specified alias for the Dev Environment.
-
#creator_id ⇒ String
The system-generated unique ID of the user who created the Dev Environment.
-
#id ⇒ String
The system-generated unique ID of the Dev Environment.
-
#ides ⇒ Array<Types::Ide>
Information about the integrated development environment (IDE) configured for the Dev Environment.
-
#inactivity_timeout_minutes ⇒ Integer
The amount of time the Dev Environment will run without any activity detected before stopping, in minutes.
-
#instance_type ⇒ String
The Amazon EC2 instace type to use for the Dev Environment.
-
#last_updated_time ⇒ Time
The time when the Dev Environment was last updated, in coordinated universal time (UTC) timestamp format as specified in [RFC 3339][1].
-
#persistent_storage ⇒ Types::PersistentStorage
Information about the amount of storage allocated to the Dev Environment.
-
#project_name ⇒ String
The name of the project in the space.
-
#repositories ⇒ Array<Types::DevEnvironmentRepositorySummary>
The source repository that contains the branch cloned into the Dev Environment.
-
#space_name ⇒ String
The name of the space.
-
#status ⇒ String
The current status of the Dev Environment.
-
#status_reason ⇒ String
The reason for the status.
Instance Attribute Details
#alias ⇒ String
The user-specified alias for the Dev Environment.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#creator_id ⇒ String
The system-generated unique ID of the user who created the Dev Environment.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The system-generated unique ID of the Dev Environment.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#ides ⇒ Array<Types::Ide>
Information about the integrated development environment (IDE) configured for the Dev Environment.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#inactivity_timeout_minutes ⇒ Integer
The amount of time the Dev Environment will run without any activity detected before stopping, in minutes.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The Amazon EC2 instace type to use for the Dev Environment.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The time when the Dev Environment was last updated, in coordinated universal time (UTC) timestamp format as specified in RFC 3339.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#persistent_storage ⇒ Types::PersistentStorage
Information about the amount of storage allocated to the Dev Environment. By default, a Dev Environment is configured to have 16GB of persistent storage.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#project_name ⇒ String
The name of the project in the space.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#repositories ⇒ Array<Types::DevEnvironmentRepositorySummary>
The source repository that contains the branch cloned into the Dev Environment.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#space_name ⇒ String
The name of the space.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Dev Environment.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
The reason for the status.
809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 809 class GetDevEnvironmentResponse < Struct.new( :space_name, :project_name, :id, :last_updated_time, :creator_id, :status, :status_reason, :repositories, :alias, :ides, :instance_type, :inactivity_timeout_minutes, :persistent_storage) SENSITIVE = [] include Aws::Structure end |