Class: Aws::CodeCatalyst::Types::RepositoryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCatalyst::Types::RepositoryInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecatalyst/types.rb
Overview
Information about a repository that will be cloned to a Dev Environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#branch_name ⇒ String
The name of the branch in a source repository.
-
#repository_name ⇒ String
The name of the source repository.
Instance Attribute Details
#branch_name ⇒ String
The name of the branch in a source repository.
1620 1621 1622 1623 1624 1625 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1620 class RepositoryInput < Struct.new( :repository_name, :branch_name) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the source repository.
1620 1621 1622 1623 1624 1625 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1620 class RepositoryInput < Struct.new( :repository_name, :branch_name) SENSITIVE = [] include Aws::Structure end |