Class: Aws::CodeCatalyst::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodeCatalyst::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codecatalyst/types.rb
Overview
The request was denied because one or more resources has reached its limits for the tier the space belongs to. Either reduce the number of resources, or change the tier if applicable.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
1651 1652 1653 1654 1655 |
# File 'lib/aws-sdk-codecatalyst/types.rb', line 1651 class ServiceQuotaExceededException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |